# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import pulumi
from enum import Enum

__all__ = [
    'Logging',
]


@pulumi.type_token("command:remote:Logging")
class Logging(_builtins.str, Enum):
    STDOUT = "stdout"
    """
    Capture stdout in logs but not stderr
    """
    STDERR = "stderr"
    """
    Capture stderr in logs but not stdout
    """
    STDOUT_AND_STDERR = "stdoutAndStderr"
    """
    Capture stdout and stderr in logs
    """
    NONE = "none"
    """
    Capture no logs
    """
